<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-06-28 10:54:20+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'es','messages'=>['Dashboard'=>'Escritorio','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Si quieres saber cómo simplificar el comercio electrónico con WordPress, prueba','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login : Si la opción comment_registration «Los usuarios deben estar registrados y conectados para comentar» está activada en tu sitio, el enlace de conexión no se ocultará en el bloque de comentarios.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login : Ten en cuenta que si marcas la opción comment_registration «Los usuarios deben estar registrados y estar conectados para comentar», el enlace de acceso no se ocultará en el bloque de comentarios.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','https://wpserveur.net'=>'https://wpserveur.net','Redirection url default'=>'URL de redirección por defecto','Redirection url'=>'URL de redirección','WordPress specialized hosting'=>'Alojamiento especializado para WordPress','Discover our other plugins:'=>'Descubre nuestros otros plugins:','the plugin'=>'el plugin','WPS Bidouille'=>'WPS Bidouille','WPS Cleaner'=>'WPS Cleaner','and'=>'y','WPS Limit Login'=>'WPS Limit Login','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Protege tu web cambiando la URL de acceso y evitando el acceso a la página «wp-login.php» y al directorio «wp-admin» a quien no esté conectado.','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Redirige la URL cuando alguien intenta acceder a la página «wp-login.php» y al directorio «wp-admin» sin haber accedido.','This has been disabled'=>'Esto ha sido desactivado','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Protege tu web cambiando la URL de acceso y evitando el acceso al archivo «wp-login.php» y al directorio «wp-admin» si no se está conectado','WPS Hide Login'=>'WPS Hide Login','Settings'=>'Ajustes','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Ahora tu página de acceso está aquí: <strong><a href="%1$s">%2$s</a></strong>. ¡Guarda esta página en tus favoritos!','Login url'=>'URL de acceso','Networkwide default'=>'Valor por defecto para toda la red','Please upgrade to the latest version of WordPress to activate'=>'Por favor, actualiza a la última versión de WordPress para activarlo','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login no se ha podido activar debido a que ya tienes activo el plugin Rename wp-login.php. Por favor, desinstala Rename wp-login.php para poder usar WPS Hide Login','This feature is not enabled.'=>'Esta característica no está activada.','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'¿Necesitas ayuda? Inténtalo en el <a href="%1$s" target="_blank">foro de soporte</a>. Este plugin te lo ofrece amablemente <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Esta opción te permite establecer un valor por defecto para toda la red, que puede ser anulado para sitios individuales. Simplemente, ve a los ajustes de los enlaces permanentes del sitio para cambiar la URL.','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Para establecer los valores por defecto para toda la red, ve a los <a href="%s">Ajustes de red</a>.']];