<?php
return ['x-generator'=>'GlotPress/4.0.2','translation-revision-date'=>'2025-10-15 13:45:15+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'nl','messages'=>['Editor NameClassic Editor'=>'Klassieke editor','Editor NameBlock editor'=>'Blok-editor','Editor NameClassic editor'=>'Klassieke editor','Editor NameEdit (classic editor)'=>'Bewerk (klassieke editor)','Editor NameEdit (block editor)'=>'Bewerk (blok-editor)','Change settings'=>'Wijzig instellingen','Default editor for all sites'=>'Standaard editor voor alle sites','Editor Settings'=>'Editor instellingen','Default Editor'=>'Standaard editor','Editor Nameblock editor'=>'Blok-editor','Editor Nameclassic editor'=>'Klassieke editor','Edit &#8220;%s&#8221; in the block editor'=>'Bewerk &#8220;%s&#8221; in de blok-editor','Switch to block editor'=>'Wissel naar blok-editor','Switch to classic editor'=>'Wissel naar klassieke editor','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Standaard wordt de blok-editor vervangen door de klassieke editor en gebruikers kunnen niet wisselen tussen editors.','Allow site admins to change settings'=>'Site beheerders toestaan instellingen te wijzigen','Editor'=>'Editor','No'=>'Nee','Yes'=>'Ja','Allow users to switch editors'=>'Sta gebruikers toe te wisselen tussen editors','Default editor for all users'=>'Standaard editor voor alle gebruikers','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress Contributors','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Schakelt de klassieke WordPress editor in en het oude stijl scherm \'Bewerk bericht\' met TinyMCE, meta boxen, enz. Ondersteunt de oudere plugins die dit scherm uitbreiden.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Bewerk &#8220;%s&#8221; in de klassieke editor','Settings'=>'Instellingen']];