<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-07-29 11:35:22+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'vi_VN','messages'=>['Editor NameClassic Editor'=>'Classic Editor','Editor NameBlock editor'=>'Trình chỉnh sửa khối','Editor NameClassic editor'=>'Classic editor','Editor NameEdit (classic editor)'=>'Edit (classic editor)','Editor NameEdit (block editor)'=>'Chỉnh sửa (block editor)','Change settings'=>'Thay đổi cài đặt','Default editor for all sites'=>'Trình soạn thảo mặc định cho tất cả trang web','Editor Settings'=>'Cài đặt trình soạn thảo','Default Editor'=>'Trình soạn thảo mặc định','Editor Nameblock editor'=>'trình soạn thảo khối','Editor Nameclassic editor'=>'classic editor','Edit &#8220;%s&#8221; in the block editor'=>'Chỉnh sửa &#8220;%s&#8221; trong trình soạn thảo khối','Switch to block editor'=>'Chuyển sang trình soạn thảo khối','Switch to classic editor'=>'Chuyển sang classic editor','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Theo mặc định, trình chỉnh sửa khối được thay thế bằng trình classic editor và người dùng không thể chuyển đổi trình soạn thảo.','Allow site admins to change settings'=>'Cho phép quản trị viên trang web thay đổi cài đặt','Editor'=>'Trình chỉnh sửa','No'=>'Không','Yes'=>'Có','Allow users to switch editors'=>'Cho phép người dùng chuyển đổi trình soạn thảo','Default editor for all users'=>'Trình soạn thảo mặc định cho tất cả người dùng','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://vi.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Cộng tác viên WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Kích hoạt trình classic editor của WordPress và màn hình Chỉnh sửa bài viết kiểu cũ với TinyMCE, Hộp meta, v.v. Hỗ trợ các plugin cũ hơn mở rộng màn hình này.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Chỉnh sửa &#8220;%s&#8221; trong classic editor','Settings'=>'Cài đặt']];