<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-10-10 15:02:53+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Disable Comments &#8211; Remove Comments &amp; Stop Spam [Multi-Site Support] - Stable (latest release)','language'=>'it','messages'=>[200=>'200',100=>'100',50=>'50',20=>'20','Don\'t Change'=>'Non cambiare','Spam:'=>'Spam:','All spam comments have been deleted.'=>'Tutti i commenti di spam sono stati eliminati.','Select All'=>'Seleziona tutto','Tab NameDelete Comments'=>'Elimina commenti','Tab NameDisable Comments'=>'Disattiva commenti','Version'=>'Versione','Off'=>'Off','On'=>'On','Disable Comments via REST API'=>'Disabilita i commenti tramite REST API','Disable Comments via XML-RPC'=>'Disabilita i commenti tramite XML-RPC','Warning:'=>'Attenzione:','Note:'=>'Nota:','Privacy'=>'Privacy','Terms Of Service'=>'Termini di servizio','Docs'=>'Documentazione','Support Forum'=>'Forum di supporto','All Plugins'=>'Tutti i plugin','About Us'=>'Chi siamo','Submit and Deactivate'=>'Invia e disattiva','Please share the reason'=>'Condividi il motivo','Other'=>'Altro','It\'s a temporary deactivation'=>'È una disattivazione temporanea','I couldn\'t get the plugin to work'=>'Non sono riuscito a far funzionare il plugin','I found a better plugin'=>'Ho trovato un plugin migliore','I no longer need the plugin'=>'Non ho più bisogno del plugin','No Thanks.'=>'No grazie.','Sorry to see you go'=>'Ci dispiace vederti andare','Sure, I\'d like to help'=>'Certo, mi piacerebbe aiutare','Saved'=>'Salvato','Disable Comments via XML-RPC. '=>'Disabilita i commenti tramite XML-RPC.','Disable Comments via REST API. '=>'Disabilita i commenti tramite REST API.','Just Deactivate'=>'Disattiva solo','settings menu titleDisable Comments'=>'Disable comments','Total Comments:'=>'Commenti totali:','Internal error occured. Please try again later.'=>'Si è verificato un errore interno. Provare più tardi.','No comments are available for deletion.'=>'Non ci sono commenti da eliminare.','Custom post types:'=>'Tipi di contenuto personalizzati:','Delete Comments'=>'Elimina i commenti','Tools'=>'Strumenti','https://wordpress.org/plugins/disable-comments/'=>'https://it.wordpress.org/plugins/disable-comments/','Save Changes'=>'Salva le modifiche','Only the built-in post types appear above. If you want to disable comments on other custom post types on the entire network, you can supply a comma-separated list of post types below (use the slug that identifies the post type).'=>'Qui sopra puoi vedere solo i tipi di contenuto (post type) predefiniti. Se vuoi disabilitare i commenti per una particolare tipologia personalizzata sull\'intero network, puoi aggiungere qui sotto una lista separata da virgole delle tipologie che ti interessano (usa gli slug che li identificano).','Disable Comments'=>'Disable Comments','Settings'=>'Impostazioni','The <strong>Disable Comments</strong> plugin is active, but isn\'t configured to do anything yet. Visit the <a href="%s">configuration page</a> to choose which post types to disable comments on.'=>'Il plugin <em>Disable Comments</em> è attivo, ma non è configurato ancora per fare niente. Visita la <a href="%s">pagina di configurazione</a> per scegliere su quali tipologie di contenuto disabilitare i commenti.',', '=>', ','Note: The <em>Disable Comments</em> plugin is currently active, and comments are completely disabled on: %s. Many of the settings below will not be applicable for those post types.'=>'Il plugin <em>Disable Comments</em> è attualmente attivo e i commenti sono completamente disabilitati su: %s. Molte delle impostazioni che seguono non saranno applicate a queste tipologie di contenuto. ','Comments are closed.'=>'I commenti sono chiusi.','Disable Comments requires WordPress version %s or greater.'=>'Disable Comments richiede la versione %s di WordPress o superiore.','All comments have been deleted'=>'Tutti i commenti sono stati eliminati','Everywhere:'=>'Ovunque:','On Certain Post Types:'=>'Su alcune tipologie di contenuto:','WPDeveloper'=>'WPDeveloper','https://wpdeveloper.com'=>'https://wpdeveloper.com']];