<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-05-05 06:00:55+0000','plural-forms'=>'nplurals=3; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'ru','messages'=>['Editor NameClassic Editor'=>'Классический редактор','Editor NameBlock editor'=>'Редактор блоков','Editor NameClassic editor'=>'Классический редактор','Editor NameEdit (classic editor)'=>'Изменить (классический редактор)','Editor NameEdit (block editor)'=>'Изменить (редактор блоков)','Change settings'=>'Изменить настройки','Default editor for all sites'=>'Редактор по умолчанию для всех сайтов','Editor Settings'=>'Настройки редактора','Default Editor'=>'Редактор по умолчанию','Editor Nameblock editor'=>'Редактор блоков','Editor Nameclassic editor'=>'Классический редактор','Edit &#8220;%s&#8221; in the block editor'=>'Редактировать &#8220;%s&#8221; в редакторе блоков','Switch to block editor'=>'Переключиться на редактор блоков','Switch to classic editor'=>'Переключиться на классический редактор','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'По умолчанию редактор блоков будет заменен на классический редактор и пользователи не смогут выбирать редактор.','Allow site admins to change settings'=>'Разрешить администраторам сайта изменять настройки','Editor'=>'Редактор','No'=>'Нет','Yes'=>'Да','Allow users to switch editors'=>'Разрешить пользователям переключение редакторов','Default editor for all users'=>'Редактор по умолчанию для всех пользователей','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://ru.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Участники разработки WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Включает классический редактор WordPress, старый вариант экрана редактирования записей (TinyMCE, мета поля и др.). Поддерживает другие плагины расширения старого редактора.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Редактировать &#8220;%s&#8221; в классическом редакторе','Settings'=>'Настройки']];