<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-07-18 08:38:52+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'ko_KR','messages'=>['Dashboard'=>'대시보드','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'워드프레스로 전자상거래를 간소화하는 방법을 알아보려면 다음을 시도해보세요.','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: 귀하의 사이트에서 "사용자는 회원가입 및 로그인해야 댓글을 남길 수 있습니다"라는 comment_registration 옵션이 활성화되어 있고, 연결 링크는 댓글 블록에서 숨겨지지 않습니다.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: comment_registration 옵션 "사용자는 회원가입 및 로그인해야 댓글을 남길 수 있습니다"를 체크하면, 로그인 링크가 댓글 블록에서 숨겨지지 않습니다.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'누군가가 로그인하지 않은 상태에서 wp-login.php 페이지와 wp-admin 디렉토리에 접근하려고 하면 URL을 리디렉션합니다.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'로그인 URL을 변경하고 wp-login.php 페이지와 wp-admin 디렉토리에 연결되지 않은 사람이 접근하지 못하도록 하여 웹사이트를 보호하세요.','WPS Limit Login'=>'WPS Limit Login','and'=>'그리고','WPS Cleaner'=>'WPS 클리너','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'플러그인','Discover our other plugins:'=>'다른 플러그인도 알아보세요:','WordPress specialized hosting'=>'워드프레스 전문 호스팅','Redirection url'=>'리디렉션 url','Redirection url default'=>'리디렉션 url 기본값','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'이것은 비활성화되었습니다','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'로그인 URL을 변경하고 로그인하지 않은 동안 wp-login.php 페이지와 wp-admin 디렉토리에 대한 액세스를 차단하여 웹사이트를 보호하세요.','This feature is not enabled.'=>'이 기능이 활성화되어 있지 않습니다.','Settings'=>'설정','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'로그인 페이지가 이제 여기에 있습니다: <strong><a href="%1$s">%2$s</a></strong> . 이 페이지를 북마크하세요!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'네트워크 전체 기본값을 설정하려면 <a href="%s">네트워크 설정</a> 으로 이동하세요.','Login url'=>'로그인 url','Networkwide default'=>'네트워크 전체 기본값','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'도움이 필요하세요? <a href="%1$s" target="_blank">지원 포럼을</a> 사용해 보세요. 이 플러그인은 <a href="%2$s" target="_blank">WPServeur</a> 에서 친절하게 제공했습니다.','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'이 옵션을 사용하면 개별 사이트에서 재정의할 수 있는 네트워크 전체 기본값을 설정할 수 있습니다. URL을 변경하려면 사이트의 고유주소 설정으로 이동하기만 하면 됩니다.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login을 활성화할 수 없습니다. Rename wp-login.php 플러그인이 이미 활성화되어 있기 때문입니다. WPS Hide Login을 사용하려면 Rename wp-login.php 플러그인을 제거하세요','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'워드프레스의 최신 버전으로 업그레이드하여 활성화하세요.']];