<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-10-09 16:54:41+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'pt_BR','messages'=>['Dashboard'=>'Painel de controle','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Se você quer descobrir como simplificar o e-commerce com o WordPress, experimente','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: Observe que se a opção comment_registration "Os usuários devem estar registrados e conectados para poderem publicar comentários" está ativada em seu site, o link de conexão não será ocultado no bloco de comentários.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: Observe que se você marcar a opção comment_registration "Os usuários devem estar registrados e conectados para poderem publicar comentários", o link de login não será ocultado no bloco de comentários.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'URL de redirecionamento quando alguém tenta acessar a página wp-login.php e o diretório wp-admin sem estar conectado.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Proteja seu site alterando a URL de login e impedindo o acesso à página wp-login.php e ao diretório wp-admin para pessoas não conectadas.','WPS Limit Login'=>'WPS Limit Login','and'=>'e','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'o plugin','Discover our other plugins:'=>'Conheça nossos outros plugins:','WordPress specialized hosting'=>'Hospedagem especializada em WordPress','Redirection url'=>'URL de redirecionamento','Redirection url default'=>'URL de redirecionamento padrão','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Isso foi desativado','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Proteja seu site alterando a URL de login e impedindo o acesso à página wp-login.php e ao diretório wp-admin enquanto não estiver conectado','This feature is not enabled.'=>'Este recurso não está ativado.','Settings'=>'Configurações','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Sua página de acesso agora está aqui: <strong><a href="%1$s">%2$s</a></strong>. Adicione aos seus favoritos!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Para definir um padrão em toda a rede, vá para <a href="%s">Configurações da rede</a>.','Login url'=>'URL de acesso','Networkwide default'=>'Padrão em toda a rede','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Precisa de ajuda? Experimente o <a href="%1$s" target="_blank">fórum de suporte</a>. Este plugin é gentilmente oferecido a você por <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Essa opção permite definir um padrão em toda a rede, que pode ser substituído por sites individuais. Basta acessar as configurações de links permanentes do site para alterar a URL.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'O WPS Hide Login não pode ser ativado porque você já tem o Rename wp-login.php ativo. Desinstale o Rename wp-login.php para utilizar o WPS Hide Login','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Atualize para a versão mais recente do WordPress para ativar.']];