<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-08-29 11:44:54+0000','plural-forms'=>'nplurals=3; plural=(n == 1) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'pl','messages'=>['Editor NameClassic Editor'=>'Klasyczny edytor','Editor NameBlock editor'=>'Edytor blokowy','Editor NameClassic editor'=>'Klasyczny edytor','Editor NameEdit (classic editor)'=>'Edytuj (klasyczny edytor)','Editor NameEdit (block editor)'=>'Edytuj (edytor blokowy)','Change settings'=>'Zmień ustawienia','Default editor for all sites'=>'Domyślny edytor dla wszystkich witryn','Editor Settings'=>'Ustawienia edytora','Default Editor'=>'Domyślny edytor','Editor Nameblock editor'=>'edytor blokowy','Editor Nameclassic editor'=>'klasyczny edytor','Edit &#8220;%s&#8221; in the block editor'=>'Edytuj &#8220;%s&#8221; w edytorze blokowym','Switch to block editor'=>'Przełącz na edytor blokowy','Switch to classic editor'=>'Przełącz na klasyczny edytor','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Domyślnie edytor blokowy jest zastępowany przez klasyczny edytor, a użytkownicy nie mogą przełączać edytorów.','Allow site admins to change settings'=>'Zezwól administratorom witryny na zmianę ustawień','Editor'=>'Edytor','No'=>'Nie','Yes'=>'Tak','Allow users to switch editors'=>'Zezwól użytkownikom na przełączanie edytorów ','Default editor for all users'=>'Domyślny edytor dla wszystkich użytkowników','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://pl.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Kontrybutorzy WordPressa','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Przywraca klasyczny edytor WordPressa wraz ze starym widokiem edycji wpisu TinyMCE, meta boxy, itp. Zapewnia wsparcie dla starszych wtyczek, które rozszerzają ten ekran.','Classic Editor'=>'Klasyczny edytor','Edit &#8220;%s&#8221; in the classic editor'=>'Edytuj &#8220;%s&#8221; w klasycznym edytorze','Settings'=>'Ustawienia']];