<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2025-11-06 13:21:35+0000','plural-forms'=>'nplurals=3; plural=(n == 1) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'pl','messages'=>['Dashboard'=>'Kokpit','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Jeśli chcesz dowiedzieć się, jak uprościć handel elektroniczny za pomocą WordPressa, wypróbuj','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: Proszę zauważyć, że opcja comment_registration „Użytkownicy muszą być zarejestrowani i zalogowani, aby komentować” jest włączona na twojej witrynie, odnośnik do połączenia nie będzie ukryty w bloku komentarzy.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: Proszę zauważyć, że jeśli zaznaczysz opcję comment_registration "Użytkownicy muszą być zarejestrowani i zalogowani, aby skomentować", odnośnik do logowania nie będzie ukryty w bloku komentarza.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Adres URL przekierowania, gdy ktoś spróbuje uzyskać dostęp to strony wp-login.php lub katalogu wp-admin, a nie jest zalogowany.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Chroń swoją witrynę, zmieniając adres URL do strony logowania i uniemożliwiając dostęp do strony wp-login.php oraz katalogu wp-admin osobom niezalogowanym.','WPS Limit Login'=>'WPS Limit Login','and'=>'oraz','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'wtyczka','Discover our other plugins:'=>'Odkryj nasze pozostałe wtyczki:','WordPress specialized hosting'=>'Specjalistyczny hosting WordPress','Redirection url'=>'Adres URL przekierowania','Redirection url default'=>'Domyślny adres URL przekierowania','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Ten element został wyłączony','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Chroń swoją stronę zmieniając URL logowania oraz blokując dostęp do wp-login.php oraz katalogu wp-admin dla niezalogowanych','This feature is not enabled.'=>'Funkcja nie jest dostępna.','Settings'=>'Ustawienia','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Twoja strona logowania znajduje się tu: <strong><a href="%1$s">%2$s</a></strong>. Dodaj ją do zakładek!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Aby ustawić domyślną wartość w całej sieci witryn, skonfiguruj <a href="%s">Ustawienia sieci</a>.','Login url'=>'Adres URL logowania','Networkwide default'=>'Domyśla wartość całej sieci','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Potrzebujesz pomocy? Wypróbuj<a href="%1$s" target="_blank">forum wsparcia</a>. Wtyczka została dostarczona przez <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Ta opcja pozawlana na ustawienie globalnych ustawień domyślnych, które moją być dostosowane dla poszczególnych stron. Przejdź do ustawień strony aby zmienić jej URL.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'Wtyczka WPS Hide Login nie może być aktywowana, ponieważ masz już aktywną wtyczkę Rename wp-login.php. Odinstaluj Rename wp-login.php aby używać WPS Hide Login','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Zaktualizuj WordPress do najnowszej wersji, aby aktywować']];