<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2025-11-21 11:52:16+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'it','messages'=>['Editor NameClassic Editor'=>'Classic Editor','Editor NameBlock editor'=>'Editor a blocchi','Editor NameClassic editor'=>'Editor classico','Editor NameEdit (classic editor)'=>'Modifica (editor classico)','Editor NameEdit (block editor)'=>'Modifica (editor a blocchi)','Change settings'=>'Cambia le impostazioni','Default editor for all sites'=>'Editor predefinito per tutti i siti','Editor Settings'=>'Impostazioni dell\'editor','Default Editor'=>'Editor predefinito','Editor Nameblock editor'=>'Editor a blocchi','Editor Nameclassic editor'=>'editor classico','Edit &#8220;%s&#8221; in the block editor'=>'Modifica &#8220;%s&#8221; con l\'editor a blocchi','Switch to block editor'=>'Passa all\'editor a blocchi','Switch to classic editor'=>'Passa all\'editor classico','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Per impostazione predefinita, l\'editor a blocchi viene sostituito con l\'editor classico e gli utenti non possono cambiare editor.','Allow site admins to change settings'=>'Consenti agli amministratori del sito di modificare le impostazioni','Editor'=>'Editor','No'=>'No','Yes'=>'Sì','Allow users to switch editors'=>'Consenti agli utenti non amministratori di cambiare la scelta del proprio editor predefinito','Default editor for all users'=>'Editor predefinito per tutti gli utenti','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://it.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Contributori WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Abilita il Classic Editor e il layout di stile precedente della schermata di modifica TinyMCE con i Meta Box, ecc. Supporta i vecchi plugin che estendono le funzionalità di questa schermata.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Modifica &#8220;%s&#8221; con l\'editor classico','Settings'=>'Impostazioni']];