<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-04-20 14:04:06+0000','plural-forms'=>'nplurals=3; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - Easy HTTPS Redirection (SSL) - Stable (latest release)','language'=>'ru','messages'=>['Enable Permalinks'=>'Использовать постоянные ссылки','Step #3: Deactivate the plugin or rename this plugin\'s folder (which will deactivate the plugin).'=>'Шаг №3: Отключите плагин или переименуйте папку этого плагина (который отключит плагин).','Step #2: Save the htaccess file (this will erase any change this plugin made to that file).'=>'Шаг №2: Сохраните файл htaccess (это приведет к удалению любого изменения, внесенного этим плагином в этот файл).','The changes will be applied immediately after saving the changes, if you are not sure - do not click the "Save changes" button.'=>'Изменения будут применены сразу после сохранения изменений, если вы не уверены - не нажимайте кнопку «Сохранить изменения».','If after making changes your site stops functioning, do the following:'=>'Если после внесения изменений ваш сайт перестает работать, выполните следующие действия:','When checked, the plugin will force load HTTPS URL for any static resources in your content. Example: if you have have an image embedded in a post with a NON-HTTPS URL, this option will change that to a HTTPS URL.'=>'Когда этот флажок установлен, плагин будет принудительно загружать URL HTTPS для любых статических ресурсов в вашем контенте. Пример: если у вас есть изображение, встроенное в сообщение с URL-адресом NON-HTTPS, этот параметр изменит это на URL-адрес HTTPS.','A few pages'=>'Некоторые страницы','The whole domain'=>'На всем домене','Use this option to make your webpage(s) load in HTTPS version only. If someone enters a non-https URL in the browser\'s address bar then the plugin will automatically redirect to the HTTPS version of that URL.'=>'Используйте этот параметр, чтобы загружать вашу веб-страницу (-ы) только в версии HTTPS. Если кто-то вводит URL-адрес не-https в адресной строке браузера, плагин автоматически перенаправляет на HTTPS-версию этого URL-адреса.','If you\'re using caching plugins similar to W3 Total Cache or WP Super Cache, you need to clear their cache after you enable or disable automatic redirection option. Failing to do so may result in mixed content warning from browser.'=>'Если вы используете кеширующие плагины, похожие на W3 Total Cache или WP Super Cache, вам необходимо очистить их кеш после включения или отключения опции автоматического перенаправления. Несоблюдение этого требования может привести к предупреждению смешанного содержимого из браузера.','Important!'=>'Важно!','Step #1: Open .htaccess file in the root directory of the WordPress install and delete everything between the following two lines'=>'Шаг №1: Откройте файл .htaccess в корневом каталоге WordPress и удалите всё между следующими двумя строками','https://www.tipsandtricks-hq.com/'=>'https://www.tipsandtricks-hq.com/','HTTPS Redirection Settings'=>'Настройки перенаправления HTTPS','Notice:'=>'Уведомление:','The plugin\'s settings have been changed. In order to save them please don\'t forget to click the \'Save Changes\' button.'=>'Настройки плагина изменены. Чтобы сохранить их, не забудьте нажать кнопку «Сохранить изменения».','Save Changes'=>'Сохранить изменения','It is very important to be extremely attentive when making changes to .htaccess file.'=>'Очень важно быть очень внимательным при внесении изменений в файл .htaccess.','When you enable the HTTPS redirection, the plugin will force redirect the URL to the HTTPS version of the URL. So before enabling this plugin\'s feature, visit your site\'s HTTPS URL %s to make sure the page loads correctly. Otherwise you may get locked out if your SSL certificate is not installed correctly on your site or the HTTPS URL is not working and this plugin is auto redirecting to the HTTPS URL.'=>'Когда вы включаете перенаправление HTTPS, плагин принудительно перенаправляет URL-адрес в HTTPS-версию URL-адреса.

Поэтому перед включением этой функции плагина посетите URL-адрес HTTPS %s вашего сайта, чтобы убедиться, что страница загружена правильно.

В противном случае вы можете быть заблокированы, если ваш SSL-сертификат установлен неправильно на вашем сайте или URL-адрес HTTPS не работает, и этот плагин автоматически перенаправляет URL-адрес HTTPS.','Settings'=>'Настройки','https://www.tipsandtricks-hq.com/wordpress-easy-https-redirection-plugin'=>'https://www.tipsandtricks-hq.com/wordpress-easy-https-redirection-plugin','The plugin HTTPS Redirection allows an automatic redirection to the "HTTPS" version/URL of the site.'=>'Плагин HTTPS Redirection позволяет автоматически перенаправлять версию HTTPS / URL сайта.','Tips and Tricks HQ'=>'Tips and Tricks HQ','Easy HTTPS (SSL) Redirection'=>'Easy HTTPS (SSL) Redirection','To enable pretty permalinks go to <em>Settings > Permalinks</em> and select any option other than "default".'=>'Чтобы включить постоянные ссылки, перейдите в <em>Настройки > Постоянные ссылки</em> и выберите любой параметр, отличный от «по умолчанию».','HTTPS redirection only works if you have pretty permalinks enabled.'=>'Переадресация HTTPS работает только в том случае, если у вас включены постоянные ссылки.']];