<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-11-01 16:50:14+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'sv_SE','messages'=>['Dashboard'=>'Adminpanel','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Om du vill veta hur du förenklar e-handel med WordPress, prova','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: Observera att alternativet ”användare måste vara registrerade och inloggade för att kunna kommentera”  för comment_registration är aktiverat på webbplatsen. Länken för inloggning kommer inte att döljas i kommentarsblocket.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: Obs! om du kryssar i alternativet ”användare måste vara registrerade och inloggade för att kunna kommentera” f;r comment_registration kommer inloggningslänken i kommentarsblocket inte att döljas.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Omdirigera URL när någon försöker komma åt sidan wp-login.php och katalogen wp-admin utan att vara inloggad.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Skydda din webbplats genom att ändra URL för inloggning och förhindra åtkomst till sidan wp-login.php och katalogen wp-admin för icke-anslutna personer.','WPS Limit Login'=>'WPS Limit Login','and'=>'och','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'tillägget','Discover our other plugins:'=>'Upptäck våra andra tillägg:','WordPress specialized hosting'=>'WordPress-specialiserat webbhotell','Redirection url'=>'URL för omdirigering','Redirection url default'=>'Standard-URL för omdirigering','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Detta har blivit inaktiverat','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Skydda din webbplats genom att ändra URL för inloggning och förhindra åtkomst till sidan wp-login.php och katalogen wp-admin när du inte är inloggad','This feature is not enabled.'=>'Denna funktion är inte aktiverad.','Settings'=>'Inställningar','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Din inloggningssida är nu här: <strong><a href="%1$s">%2$s</a></strong>. Bokmärk denna sida!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'För att ställa in standard för hela nätverket, gå till <a href="%s">nätverksinställningar</a>.','Login url'=>'URL för inloggning','Networkwide default'=>'Standard för hela nätverket','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Behöver du hjälp? Prova <a href="%1$s" target="_blank">supportforumet</a>. Detta tillägg levereras till dig av <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Detta alternativ låter dig ställa in standard för hela nätverket som kan åsidosättas av enskilda webbplatser. Gå helt enkelt till webbplatsens permalänkinställningar för att ändra URL:en.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login kunde inte aktiveras eftersom du redan har Rename wp-login.php aktivt. Avinstallera rename wp-login.php för att använda WPS Hide Login','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Uppgradera till den senaste versionen av WordPress för att aktivera']];