<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-11-23 07:13:58+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'es','messages'=>['Editor NameClassic Editor'=>'Editor clásico','Editor NameBlock editor'=>'Editor de bloques','Editor NameClassic editor'=>'Editor clásico','Editor NameEdit (classic editor)'=>'Editar (editor clásico)','Editor NameEdit (block editor)'=>'Editar (editor de bloques)','Change settings'=>'Cambiar los ajustes','Default editor for all sites'=>'Editor por defecto para todos los sitios','Editor Settings'=>'Ajustes del editor','Default Editor'=>'Editor por defecto','Editor Nameblock editor'=>'editor de bloques','Editor Nameclassic editor'=>'editor clásico','Edit &#8220;%s&#8221; in the block editor'=>'Editar «%s» en el editor de bloques','Switch to block editor'=>'Cambiar al editor de bloques','Switch to classic editor'=>'Cambiar al editor clásico','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Por defecto, el editor de bloques es reemplazado con el editor clásico y los usuarios no pueden cambiar entre editores.','Allow site admins to change settings'=>'Permitir a los administradores de sitios cambiar los ajustes','Editor'=>'Editor','No'=>'No','Yes'=>'Sí','Allow users to switch editors'=>'Permitir a los usuarios cambiar de editor','Default editor for all users'=>'Editor por defecto para todos los usuarios','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://es.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Colaboradores de WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Activa el editor clásico de WordPress y el estilo tradicional de la pantalla de edición de entradas con TinyMCE, cajas meta, etc. Es compatible con los plugins antigüos que amplían esta pantalla.','Classic Editor'=>'Editor clásico','Edit &#8220;%s&#8221; in the classic editor'=>'Editar «%s» en el editor clásico','Settings'=>'Ajustes']];