<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-07-01 17:02:05+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'fr','messages'=>['WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Si vous voulez trouver comment vous simplifier la vie avec le e-commerce avec WordPress, essayez','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login : Veuillez noter que si vous cochez l’option d’enregistrement des commentaires « Les utilisateurs et utilisatrices doivent être enregistrés et connectés pour commenter », le lien de connexion ne sera pas caché dans le bloc de commentaires.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Redirige l’URL lorsque quelqu’un essaie d’accéder à la page wp-login.php et au répertoire wp-admin sans être connecté.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Protégez votre site en modifiant l’URL de connexion et en empêchant l’accès à la page wp-login.php et au répertoire wp-admin aux personnes non connectées.','WPS Limit Login'=>'WPS Limit Login','and'=>'et','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'L’extension','Discover our other plugins:'=>'Découvrez nos autres extensions :','WordPress specialized hosting'=>'Hébergement spécialisé pour WordPress','Redirection url'=>'URL de redirection ','Redirection url default'=>'URL de redirection par défaut','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Cela a été désactivé','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Protégez votre site Web en changeant l’URL de connexion et en empêchant l’accès à la page wp-login.php et au répertoire wp-admin aux personnes non-connectées. ','This feature is not enabled.'=>'Cette fonctionnalité n’est pas activée.','Settings'=>'Réglages','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Votre page de connexion est maintenant ici : <strong><a href="%1$s">%2$s</a></strong>. Mettez-la en favori !','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Pour définir un réglage par défaut pour le réseau, allez aux <a href="%s">réglages du réseaux</a>.','Login url'=>'URL de connexion','Networkwide default'=>'Réglage par défaut du réseau','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Besoin d’aide ? Essayez le <a href="%1$s" target="_blank">forum de support</a>. Cette extension vous est gentiment proposée par <a href="%2$s" target="_blank">WPServeur</a>.','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Cette option vous permet de définir un réglage par défaut pour le réseau, qui peut ensuite être remplacé pour chaque site individuellement. Allez simplement dans les réglages des permaliens du site pour modifier l’URL.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login n’a pas pu être activé car vous avez déjà Rename wp-login.php activé. Veuillez désinstaller Rename wp-login.php pour pouvoir utiliser WPS Hide Login.','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Veuillez mettre à jour WordPress dans sa dernière version pour activer']];