<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-05-20 06:27:05+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'zh_TW','messages'=>['Editor NameClassic Editor'=>'傳統編輯器','Editor NameBlock editor'=>'區塊編輯器','Editor NameClassic editor'=>'傳統編輯器','Editor NameEdit (classic editor)'=>'編輯 (傳統編輯器)','Editor NameEdit (block editor)'=>'編輯 (區塊編輯器)','Change settings'=>'變更設定','Default editor for all sites'=>'全部網站的預設編輯器','Editor Settings'=>'編輯器設定','Default Editor'=>'預設編輯器','Editor Nameblock editor'=>'區塊編輯器','Editor Nameclassic editor'=>'傳統編輯器','Edit &#8220;%s&#8221; in the block editor'=>'使用區塊編輯器編輯〈%s〉','Switch to block editor'=>'切換至區塊編輯器','Switch to classic editor'=>'切換至傳統編輯器','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'依照預設，區塊編輯器會取代傳統編輯器，且使用者無法切換編輯器。','Allow site admins to change settings'=>'開放網站管理員變更設定','Editor'=>'編輯器','No'=>'否','Yes'=>'是','Allow users to switch editors'=>'開放使用者自行切換編輯器','Default editor for all users'=>'全站預設編輯器','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://tw.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress Contributors','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'將 WordPress 網站的編輯器還原為傳統編輯器及舊式 [編輯文章] 畫面 (例如 TinyMCE、中繼資料區塊等等)，同時也支援其他能擴充這個畫面的外掛。','Classic Editor'=>'Classic Editor (傳統編輯器)','Edit &#8220;%s&#8221; in the classic editor'=>'使用傳統編輯器編輯〈%s〉','Settings'=>'設定']];