<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-08-18 02:59:44+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Disable Comments &#8211; Remove Comments &amp; Stop Spam [Multi-Site Support] - Stable (latest release)','language'=>'ja_JP','messages'=>['Search sites'=>'サイトを検索','Available post types'=>'利用可能な投稿タイプ','Spam:'=>'スパム:','Select All'=>'すべて選択','Select your sub-sites where you want to delete comments.'=>'削除したいコメントがあるサブサイトを選んでください。','Tab NameDelete Comments'=>'コメントを削除','Tab NameDisable Comments'=>'コメントを無効化','Version'=>'バージョン','Off'=>'オフ','On'=>'オン','Disable Comments With API'=>'API でのコメントを無効化','On Specific Post Types:'=>'特定の投稿タイプに対して:','Read Our Tutorials'=>'チュートリアルを読む','Delete Certain Comment Types:'=>'特定のタイプのコメントを削除:','Disable comments globally on your entire website'=>'ご使用中のウェブサイト全体でコメントを無効化','Disable Comments For WordPress Pages'=>'WordPress 固定ページでコメントを無効化','Disable Comment For WordPress Media Files'=>'WordPress メディアファイルへのコメントを無効化','Disable Comments For Some Particular Post'=>'個別の投稿に対するコメントを無効化','Disable Comments via REST API'=>'REST API からのコメントを無効化','Disable Comments via XML-RPC'=>'XML-RPC からのコメントを無効化','Warning:'=>'警告:','Other'=>'その他','Note:'=>'注:','Docs'=>'ドキュメンテーション','Saved'=>'保存しました','Privacy'=>'プライバシー','I found a better plugin'=>'もっと良いプラグインを見つけた','I no longer need the plugin'=>'プラグインが必要がなくなった','Submit and Deactivate'=>'送信して無効化','Support Forum'=>'サポートフォーラム','All Plugins'=>'すべてのプラグイン','About Us'=>'私たちについて','Just Deactivate'=>'無効化のみ','Terms Of Service'=>'利用規約','No Thanks.'=>'いえ、結構です。','Sure, I\'d like to help'=>'もちろん協力しましょう','What we collect.'=>'収集する事柄。','Disable Comments via REST API. '=>'REST API でコメントを無効化。','Disable Comments via XML-RPC. '=>'XML-RPC でコメントを無効化','Custom post types: %s. '=>'カスタム投稿タイプ: %s 。','Submitting form'=>'フォーム送信中','Please share the reason'=>'理由をご記入ください','It\'s a temporary deactivation'=>'一時的な無効化です','Total Comments:'=>'コメント合計: ','Internal error occured. Please try again later.'=>'内部エラーが発生しました。後でもう一度お試しください。','No comments are available for deletion.'=>'削除可能なコメントはありません。','Custom post types:'=>'カスタム投稿タイプ: ','Delete Comments'=>'コメントの削除','Tools'=>'ツール','https://wordpress.org/plugins/disable-comments/'=>'https://ja.wordpress.org/plugins/disable-comments/','Save Changes'=>'変更を保存','Only the built-in post types appear above. If you want to disable comments on other custom post types on the entire network, you can supply a comma-separated list of post types below (use the slug that identifies the post type).'=>'ビルトイン投稿タイプのみが上に表示されます。ネットワーク全体で他のカスタム投稿タイプのコメントを無効化したい場合は、投稿タイプをカンマ区切りで下に入力してください (投稿タイプを識別するスラッグを使ってください) 。','Disable Comments'=>'Disable Comments','Settings'=>'設定','The <strong>Disable Comments</strong> plugin is active, but isn\'t configured to do anything yet. Visit the <a href="%s">configuration page</a> to choose which post types to disable comments on.'=>'<em>Disable Comments</em> プラグインが有効化されていますが、まだ何も設定が行われていません。<a href="%s">設定ページ</a>ヘ移動し、コメントを無効化する投稿タイプを選択してください。',', '=>'、','Note: The <em>Disable Comments</em> plugin is currently active, and comments are completely disabled on: %s. Many of the settings below will not be applicable for those post types.'=>'注: <em>Disable Comments</em> プラグインが現在有効化されており、%s 上のコメントが完全に無効になっています。 以下の設定の多くは、これらの投稿タイプには適用されません。','Comments are closed.'=>'コメントは受け付けていません。','Disable Comments requires WordPress version %s or greater.'=>'Disable Comments プラグインには WordPress バージョン %s 以降が必要です。','WPDeveloper'=>'WPDeveloper','https://wpdeveloper.com'=>'https://wpdeveloper.net','Everywhere:'=>'どこでも:','All comments have been deleted'=>'すべてのコメントを削除しました','On Certain Post Types:'=>'特定の投稿タイプに対して:']];