<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-01-13 14:52:07+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'tr','messages'=>['Dashboard'=>'Kontrol paneli','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'WordPress ile e-ticareti nasıl basitleştirebileceğinizi öğrenmek istiyorsanız, deneyin','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Giriş Gizleme: Lütfen sitenizde “Kullanıcılar yorum yapmak için kayıtlı ve oturum açmış olmalıdır” yorum kaydı seçeneğinin etkinleştirildiğini unutmayın, bağlantı bağlantısı yorum bloğunda gizlenmeyecektir.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Giriş Gizle: comment_registration seçeneği “Kullanıcılar yorum yapmak için kayıtlı ve oturum açmış olmalıdır” seçeneğini işaretlerseniz, yorum bloğunda giriş bağlantısı gizlenmeyecektir.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Birisi oturum açmamışken wp-login.php sayfasına ve wp-admin dizinine erişmeye çalıştığında URL\'yi yeniden yönlendirin.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Giriş URL\'sini değiştirerek ve wp-login.php sayfasına ve wp-admin dizinine bağlı olmayan kişilerin erişimini engelleyerek web sitenizi koruyun.','WPS Limit Login'=>'WPS Limit Login','and'=>'ve','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'eklenti','Discover our other plugins:'=>'Diğer eklentilerimizi keşfedin:','WordPress specialized hosting'=>'WordPress için özel hosting','Redirection url'=>'Yönlendirme URL\'si','Redirection url default'=>'Varsayılan yönlendirme URL\'si','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Bu devre dışı bırakıldı','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Web sitenizi, giriş URL’sini değiştirerek ve giriş yapmadığınızda wp-login.php sayfasına ve wp-admin dizinine erişimi engelleyerek koruyun','This feature is not enabled.'=>'Bu özellik etkin değil.','Settings'=>'Ayarlar','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Giriş sayfanız artık burada: <strong><a href="%1$s">%2$s</a></strong>. Bu sayfayı yer imlerine ekleyin!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Ağ çapında bir varsayılan ayarlamak için, <a href="%s"> Ağ Ayarları </a> \'na gidin.','Login url'=>'Giriş URL\'si','Networkwide default'=>'Ağ çapında varsayılan','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Yardıma ihtiyacınız mı var? <a href="%1$s" target="_blank">destek forumunu</a> deneyin. Bu eklenti size <a href="%2$s" target="_blank">WPServeur</a> tarafından sunulmaktadır.','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Bu seçenek, ağ genelinde geçerli olacak bir varsayılan ayar belirlemenizi sağlar. Bu ayar, tek tek siteler tarafından geçersiz kılınabilir. URL\'yi değiştirmek için sitenin kalıcı bağlantı ayarlarına gidin.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login, wp-login.php\'yi yeniden adlandırma özelliği zaten etkin olduğu için etkinleştirilemedi. WPS Hide Login\'i kullanmak için wp-login.php\'yi yeniden adlandırma özelliğini kaldırın.','WPS Hide Login'=>'WPS Giriş Gizle','Please upgrade to the latest version of WordPress to activate'=>'Etkinleştirmek için lütfen en son WordPress sürümüne yükseltin']];