<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-06-15 11:19:54+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'de','messages'=>['Dashboard'=>'Dashboard','WPBoutik'=>'WPBoutik','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: Bitte beachte, dass wenn die comment_registration-Option „Benutzer müssen registriert und angemeldet sein, um zu kommentieren“ auf deiner Website aktiviert ist, der Verbindungslink im Kommentarblock nicht versteckt sein wird.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: Bitte beachte, dass der Anmelde-Link im Kommentarblock nicht ausgeblendet wird, wenn du die comment_registration-Option „Benutzer müssen registriert und angemeldet sein, um zu kommentieren“ aktivierst.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Weiterleitungs-URL, wenn jemand nicht angemeldet ist und versucht, auf die wp-login.php-Seite oder das wp-admin-Verzeichnis zuzugreifen.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Schütze deine Website, indem du die Login-URL änderst und verhindere den Zugriff auf die wp-login.php-Seite und das wp-admin-Verzeichnis für nicht angemeldete Personen.','WPS Limit Login'=>'WPS Limit Login','and'=>'und','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'das Plugin','Discover our other plugins:'=>'Entdecke auch unsere anderen Plugins:','WordPress specialized hosting'=>'Auf WordPress spezialisiertes Hosting','Redirection url'=>'Umleitungs-URL','Redirection url default'=>'Standard-URL für Weiterleitung','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Das wurde gesperrt','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Schütze deine Website, indem du die Anmelde-URL änderst und den Zugang zur Seite wp-login.php und dem Verzeichnis wp-admin verhinderst, wenn man nicht angemeldet ist','This feature is not enabled.'=>'Diese Funktion ist nicht aktiviert.','Settings'=>'Einstellungen','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Deine Anmelde-Seite befindet sich nun hier: <strong><a href="%1$s">%2$s</a></strong>. Lege ein Lesezeichen für diese Seite an!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Um einen netzwerkweiten Standard zu setzen, gehe zu den <a href="%s">Netzwerkeinstellungen</a>.','Login url'=>'Anmelde-URL','Networkwide default'=>'Netzwerkweite Vorgabe','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Wenn du Hilfe benötigst, sieh im <a href="%1$s" target="_blank">Supportforum</a> nach. Dieses Plugin wurde dir freundlicherweise von <a href="%2$s" target="_blank">WPServeur</a> zur Verfügung gestellt','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Diese Option ermöglicht dir, eine netzwerkweite Vorgabe zu machen, die von einzelnen Websites ausgehebelt werden kann. Gehe einfach auf die Permalink-Einstellungen der Website, um die URL zu ändern.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login konnte nicht aktiviert werden, weil du bereits Rename wp-login.php aktiviert hast. Bitte deinstalliere Rename wp-login.php, um WPS Hide Login verwenden zu können','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Bitte führe ein Upgrade auf die aktuelle Version von WordPress durch, um das Plugin aktivieren zu können']];