<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-04-24 09:19:15+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'da_DK','messages'=>['WPBoutik'=>'WPBoutik','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','https://wpserveur.net'=>'https://wpserveur.net','WordPress specialized hosting'=>'WordPress specialiseret hosting','Discover our other plugins:'=>'Oplev vores øvrige plugins:','the plugin'=>'pluginet','and'=>'og','WPS Bidouille'=>'WPS Bidouille','WPS Cleaner'=>'WPS Cleaner','WPS Limit Login'=>'WPS Limit Login','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Beskyt dit websted ved at ændre login URL og forhindre adgang til siden wp-login.php og wp-admin mappen for ikke tilsluttede personer.','Redirection url default'=>'Standard URL-viderestilling','Redirection url'=>'Viderestillings-URL','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Viderestil URL, når nogen forsøger at få adgang til wp-login.php-siden og wp-admin mappen, når de ikke er logget ind.','This has been disabled'=>'Dette er blevet deaktiveret','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Beskyt dit websted ved at ændre login-URL og forhindre adgang til wp-login.php siden og wp-admin mappen, når man ikke er logget ind.','Settings'=>'Indstillinger','This feature is not enabled.'=>'Denne funktion er ikke aktiveret.','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Din login-side er nu her: <strong><a href="%1$s">%2$s</a></strong> Gem denne side!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'For at indstille hele netværkets standard,  <a href="%s">Netværks indstillinger</a>.','Login url'=>'Login URL','Networkwide default'=>'Hele netværkets standard','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Denne indstilling gør det muligt at indstille hele netværkets standard, hvilket kan tilsidesættes af individuelle websteder. Du skal blot gå til til webstedets permalink indstillinger for at ændre URL\'en.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login kunne ikke aktiveres, fordi du allerede har omdøbt wp-login.php. Fjern omdøbningen af wp-login.php, før du bruger WPS Hide Login.','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Opgrader til den nyeste version af WordPress for at aktivere.','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Brug for hjælp? Prøv <a href="%1$s" target="_blank">Support forummet</a>. Dette plugin er venligts bragt til dig af <a href="%2$s" target="_blank">WPServeur</a>.']];