<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-09-19 23:39:47+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'de','messages'=>['Editor NameClassic Editor'=>'Classic Editor','Editor NameBlock editor'=>'Block-Editor','Editor NameClassic editor'=>'Classic Editor','Editor NameEdit (classic editor)'=>'Bearbeiten [Classic Editor]','Editor NameEdit (block editor)'=>'Bearbeiten [Block-Editor]','Change settings'=>'Einstellungen ändern','Default editor for all sites'=>'Standard-Editor für alle Websites','Editor Settings'=>'Editor-Einstellungen','Default Editor'=>'Standard-Editor','Editor Nameblock editor'=>'Block-Editor','Editor Nameclassic editor'=>'„Classic Editor“','Edit &#8220;%s&#8221; in the block editor'=>'&#8222;%s&#8220; im Block-Editor bearbeiten','Switch to block editor'=>'Zum Block-Editor wechseln','Switch to classic editor'=>'Zum „Classic Editor“ wechseln','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Standardmäßig wird der Block-Editor durch den „Classic Editor“ ersetzt und Benutzer können zwischen den Editoren nicht wechseln.','Allow site admins to change settings'=>'Website-Administratoren erlauben, Einstellungen zu ändern','Editor'=>'Editor','No'=>'Nein','Yes'=>'Ja','Allow users to switch editors'=>'Benutzern erlauben, den Editor zu wechseln','Default editor for all users'=>'Standard-Editor für alle Benutzer','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://de.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress-Mitwirkende','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Aktiviert den bisherigen klassischen WordPress-Editor, sowie die Bearbeiten-Ansicht im alten Stil mit TinyMCE, Metaboxen usw. für Beiträge und Seiten. Unterstützt außerdem alle Plugins, die diese Ansicht erweitern.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'&#8222;%s&#8220; im „Classic Editor“ bearbeiten','Settings'=>'Einstellungen']];