<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2024-05-23 23:08:29+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - FileOrganizer &#8211; WordPress File Manager - Stable (latest release)','language'=>'fr','messages'=>['here'=>'ici','or through Our Premium Support Ticket System at'=>'ou par l’intermédiaire de notre système de tickets de support Premium à','You can contact the FileOrganizer Team via email. Our email address is'=>'Vous pouvez contacter l’équipe de FileOrganizer par e-mail. Notre adresse e-mail est','Enable network volume.'=>'Activer le volume réseau.','Enable Network Volume'=>'Activer le volume réseau','MB'=>'Mo','Maximum Upload Size'=>'Taille maximale de téléversement','Enabling access to the FileOrganizer for User Roles'=>'Activer l’accès à FileOrganizer pour les rôles','Shop Manager'=>'Gestionnaire de boutique','Customer'=>'Client/cliente','Subscriber'=>'Abonné/abonnée','Contributor'=>'Contributeur/contributrice','Author'=>'Auteur/autrice','Editor'=>'Éditeur/éditrice','Administrator'=>'Administrateur/administratrice','Allowed User Roles'=>'Rôles autorisés','Available in Pro version!'=>'Disponible dans la version Pro !','The trash files are saved in the following path.'=>'Les fichiers corbeille sont enregistrés dans le chemin d’accès suivant.','List'=>'Liste','Icons'=>'Icônes','File Manager Path'=>'Chemin d’accès au gestionnaire de fichiers','Support'=>'Support','Advanced'=>'Avancé','General'=>'Général','Settings saved successfully.'=>'Réglages bien enregistrés.','Invalid File Manager Path Detected!'=>'Chemin d’accès au gestionnaire de fichiers non valide détecté !','Windows 10'=>'Windows 10','Material Light'=>'Matériel clair','Material Dark'=>'Matériel sombre','Material'=>'Matériel','Dark'=>'Sombre','Default'=>'Par défaut','Theme'=>'Thème','License'=>'Licence','User Role Restrictions'=>'Restrictions par rôle','User Restrictions'=>'Restrictions pour les comptes','Settings'=>'Réglages','Enable Trash?'=>'Activer la corbeille ?','Hide .htaccess file if exists.'=>'Masquer le fichier .htaccess s’il existe.','Hide .htaccess?'=>'Masquer .htaccess ?','Change the FileOrganizer default language.'=>'Modifier la langue par défaut de FileOrganizer.','Select Language'=>'Sélectionner la langue','Set default folder view.'=>'Définir la vue par défaut des dossiers.','Files View'=>'Vue des fichiers','Allow FileOrganizer to set a path outside of your WordPress installation.'=>'Permettre à FileOrganizer de définir un chemin d’accès en dehors de votre installation WordPress.','Disable root path restriction.'=>'Désactiver la restriction du chemin d’accès à la racine.','File Manager Path Restriction'=>'Restriction du chemin d’accès au gestionnaire de fichiers','Let your followers know that you use FileOrganizer to manage your wordpress files :'=>'Faites savoir à vos abonnés que vous utilisez FileOrganizer pour gérer vos fichiers WordPress :','File Organizer'=>'Organisateur de fichiers','FILE ORGANIZER'=>'Organisateur de fichiers','https://fileorganizer.net'=>'https://fileorganizer.net','Softaculous Team'=>'Équipe Softaculous','https://wordpress.org/plugins/fileorganizer/'=>'https://wordpress.org/plugins/fileorganizer/','FileOrganizer'=>'FileOrganizer','FileOrganizer is a plugin that helps you to manage all files in your WordPress Site.'=>'FileOrganizer est une extension qui vous aide à gérer tous les fichiers de votre site WordPress.']];