<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-01-26 15:11:39+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'pt_BR','messages'=>['Editor NameClassic Editor'=>'Editor clássico','Editor NameBlock editor'=>'Editor de blocos','Editor NameClassic editor'=>'Editor clássico','Editor NameEdit (classic editor)'=>'Editar (Editor clássico)','Editor NameEdit (block editor)'=>'Editar (Editor de blocos)','Change settings'=>'Mudar configurações','Default editor for all sites'=>'Editor padrão para todos os sites','Editor Settings'=>'Configurações do editor','Default Editor'=>'Editor padrão','Editor Nameblock editor'=>'Editor de blocos','Editor Nameclassic editor'=>'Editor clássico','Edit &#8220;%s&#8221; in the block editor'=>'Editar &#8220;%s&#8221; no editor de blocos','Switch to block editor'=>'Mudar para o editor de blocos','Switch to classic editor'=>'Mudar para o editor clássico','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Por padrão o editor de blocos é substituído pelo editor clássico e os usuários não poderão alternar entre editores.','Allow site admins to change settings'=>'Permitir que os administradores do site alterem as configurações','Editor'=>'Editor','No'=>'Não','Yes'=>'Sim','Allow users to switch editors'=>'Permitir que os usuários alternem entre editores','Default editor for all users'=>'Editor padrão para todos os usuários','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://br.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Colaboradores do WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Ativa o editor clássico do WordPress e o antigo estilo da tela de edição de posts com TinyMCE, meta boxes e etc. Suporta plugins antigos que estendem a tela antiga de edição de posts.','Classic Editor'=>'Editor clássico','Edit &#8220;%s&#8221; in the classic editor'=>'Editar &#8220;%s&#8221; no editor clássico','Settings'=>'Configurações']];