<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-01-15 02:51:21+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'ko_KR','messages'=>['Editor NameClassic Editor'=>'Classic Editor','Editor NameBlock editor'=>'블록 편집기','Editor NameClassic editor'=>'Classic editor','Editor NameEdit (classic editor)'=>'편집 (클래식 편집기)','Editor NameEdit (block editor)'=>'편집하기(블록 편집기)','Change settings'=>'설정 변경','Default editor for all sites'=>'모든 사이트에 대한 기본 편집기','Editor Settings'=>'편집기 설정','Default Editor'=>'기본 편집기','Editor Nameblock editor'=>'블록 편집기','Editor Nameclassic editor'=>'classic editor','Edit &#8220;%s&#8221; in the block editor'=>'블록 편집기에서 &#8220;%s&#8221; 편집하기','Switch to block editor'=>'블록 편집기로 전환','Switch to classic editor'=>'클래식 편집기로 전환','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'기본적으로 블록 편집기는 클래식 편집기로 대체되며 사용자는 편집기를 전환할 수 없습니다.','Allow site admins to change settings'=>'모든 사이트 관리자가 설정을 변경하도록 허용','Editor'=>'편집기','No'=>'아니오','Yes'=>'네','Allow users to switch editors'=>'모든 이용자가 편집기를 전환하도록 허용','Default editor for all users'=>'모든 이용자에 대한 기본 편집기','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'워드프레스 기여자','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'워드프레스 클래식 편집기와 TinyMCE, 메타박스 등이 포함된 이전 스타일의 글 편집 화면을 활성화합니다. 이 화면을 확장하는 이전 플러그인을 지원합니다.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'클래식 편집기에서 &#8220;%s&#8221; 편집','Settings'=>'설정']];