<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-12-07 16:45:35+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'nb_NO','messages'=>['Editor NameClassic Editor'=>'Klassisk redigeringsverktøy','Editor NameBlock editor'=>'Blokkredigering','Editor NameClassic editor'=>'Klassisk redigering','Editor NameEdit (classic editor)'=>'Rediger (klassisk redigering)','Editor NameEdit (block editor)'=>'Rediger (blokkredigering)','Change settings'=>'Endre innstillinger','Default editor for all sites'=>'Standard redigeringsverktøy for alle nettsteder','Editor Settings'=>'Innstillinger for redigeringsverktøyet','Default Editor'=>'Standard redigeringsverktøy','Editor Nameblock editor'=>'blokkredigering','Editor Nameclassic editor'=>'klassisk redigering','Edit &#8220;%s&#8221; in the block editor'=>'Rediger &#8220;%s&#8221; i blokkredigeringsverktøyet','Switch to block editor'=>'Bytt til blokkredigering','Switch to classic editor'=>'Bytt til klassisk redigering','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Som standard blir blokkredigering erstattet av med den klassiske redigeringen og brukere kan ikke selv bytte redigeringsverktøy.','Allow site admins to change settings'=>'Tillat nettstedsadministratorer å endre innstillingene','Editor'=>'Redigeringsverktøy','No'=>'Nei','Yes'=>'Ja','Allow users to switch editors'=>'Tillat brukere å bytte redigeringsverktøy','Default editor for all users'=>'Standard redigeringsverktøy for alle brukere','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://nb.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Bidragsytere til WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Aktiverer den klassiske WordPress-redigeringen og den gamle \'Rediger innlegg\'-skjermen med TinyMCE, metabokser osv. Støtter de eldre utvidelsene som utvider denne skjermen.','Classic Editor'=>'Klassisk redigering','Edit &#8220;%s&#8221; in the classic editor'=>'Rediger &#8220;%s&#8221; i det klassiske redigeringsverktøyet','Settings'=>'Innstillinger']];