<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-10-09 17:57:44+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'nl','messages'=>['Dashboard'=>'Dashboard','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Je wilt ontdekken hoe je e-commerce kunt vereenvoudigen met WordPress, probeer','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: let op dat de optie "Gebruikers moeten geregistreerd en ingelogd zijn om te kunnen reageren" geactiveerd is op je site, de verbindingslink niet verborgen zal worden op het reactieblok.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: let op, als je de optie comment_registration aanvinkt "Gebruikers moeten geregistreerd en ingelogd zijn om te reageren", zal de login link niet verborgen worden op het reactieblok.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Omleiding URL wanneer iemand probeert toegang te krijgen tot de wp-login.php pagina en de wp-admin folder terwijl hij niet is ingelogd.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Bescherm je site door de login URL te wijzigen en toegang tot de wp-login.php pagina en de wp-admin folder te verhinderen voor niet verbonden personen.','WPS Limit Login'=>'WPS Limit Login','and'=>'en','WPS Cleaner'=>'WPS reiniger','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'de plugin','Discover our other plugins:'=>'Ontdek onze andere plugins:','WordPress specialized hosting'=>'WordPress gespecialiseerde hosting','Redirection url'=>'Omleiding url','Redirection url default'=>'Standaard omleiding URL','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Dit werd uitgeschakeld','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Bescherm je site door de login URL te wijzigen en toegang tot de wp-login.php pagina en wp-admin folder te voorkomen, terwijl je niet bent ingelogd','This feature is not enabled.'=>'Deze functie is niet ingeschakeld.','Settings'=>'Instellingen','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Je login pagina is nu hier: <strong><a href="%1$s">%2$s</a></strong>. Maak een bladwijzer van deze pagina !','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Om geen standaard waarde voor he hele netwerk in te stellen, ga naar <a href="%s">Netwerk instellingen</a>.','Login url'=>'Login url','Networkwide default'=>'Netwerkwijde standaard','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Hulp nodig? Probeer het <a href="%1$s" target="_blank">ondersteuning forum</a>. Deze plugin word je gebracht door <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Deze optie stelt je in staat om een netwerkbrede standaard in te stellen, die overschreven kan worden door individuele sites. Ga eenvoudigweg naar de permalink instellingen van de site om de URL te wijzigen.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'WPS Hide Login kan niet worden geactiveerd omdat je reeds hernoemen wp-login.php actief hebt. Verwijder de naam rename wp-login.php om WPS Hide Login te gebruiken','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Voer een upgrade uit naar de nieuwste versie van WordPress om te activeren']];