<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-04-08 11:56:23+0000','plural-forms'=>'nplurals=3; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'uk_UA','messages'=>['Editor NameClassic Editor'=>'Класичний редактор','Editor NameBlock editor'=>'Редактор блоків','Editor NameClassic editor'=>'Класичний редактор','Editor NameEdit (classic editor)'=>'Редагувати (класичний редактор)','Editor NameEdit (block editor)'=>'Редагувати (редактор блоків)','Change settings'=>'Змінити налаштування','Default editor for all sites'=>'Редактор за замовчуванням для всіх сайтів','Editor Settings'=>'Налаштування редактора','Default Editor'=>'Редактор за замовчуванням','Editor Nameblock editor'=>'редактор блоків','Editor Nameclassic editor'=>'класичний редактор','Edit &#8220;%s&#8221; in the block editor'=>'Редагувати &#8220;%s&#8221; в редакторі блоків','Switch to block editor'=>'Переключитися на редактор блоків','Switch to classic editor'=>'Переключитися на класичний редактор','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'За замовчуванням редактор блоків буде замінений на класичний редактор і користувачі не зможуть вибирати редактор.','Allow site admins to change settings'=>'Дозволити адміністраторам сайту змінювати налаштування','Editor'=>'Редактор','No'=>'Ні','Yes'=>'Так','Allow users to switch editors'=>'Дозволити користувачам перемикання редакторів','Default editor for all users'=>'Редактор за замовчуванням для всіх користувачів','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://uk.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress Contributors','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Вмикає класичний редактор WordPress, старий варіант екрану редагування записів (TinyMCE, мета поля та ін.). Підтримує інші плагіни розширення старого редактора.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Редагувати &#8220;%s&#8221; в класичному редакторі','Settings'=>'Налаштування']];