<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-05-16 08:34:19+0000','plural-forms'=>'nplurals=2; plural=n > 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'fr','messages'=>['Editor NameClassic Editor'=>'Classic Editor','Editor NameBlock editor'=>'Éditeur de blocs','Editor NameClassic editor'=>'Éditeur classique','Editor NameEdit (classic editor)'=>'Modifier (Classic Editor)','Editor NameEdit (block editor)'=>'Modifier (Nouvel éditeur)','Change settings'=>'Modifier les réglages','Default editor for all sites'=>'Éditeur par défaut pour tous le sites','Editor Settings'=>'Réglages de l’éditeur','Default Editor'=>'Éditeur par défaut','Editor Nameblock editor'=>'Nouvel éditeur','Editor Nameclassic editor'=>'Éditeur classique','Edit &#8220;%s&#8221; in the block editor'=>'Modifier &#171; %s &#187; dans l’éditeur de blocs','Switch to block editor'=>'Changer vers le nouvel éditeur','Switch to classic editor'=>'Basculer vers l’éditeur classique','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Par défaut, le nouvel éditeur est remplacé par l’éditeur classique et les utilisateurs ne peuvent pas changer d’éditeur.','Allow site admins to change settings'=>'Autoriser les administrateurs et les administratrices à modifier les réglages','Editor'=>'Éditeur','No'=>'Non','Yes'=>'Oui','Allow users to switch editors'=>'Autoriser les utilisateurs et utilisatrices à changer d’éditeur','Default editor for all users'=>'Éditeur par défaut pour tous les utilisateurs et utilisatrices','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Contributeurs et contributrices WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Active l’éditeur classique de WordPress et l’ancienne disposition de l’écran de modification d’article (TinyMCE, boites à méta, etc.). Prend en charge les anciennes extensions qui étendent cet écran.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Modifier « %s » dans l’éditeur classique','Settings'=>'Réglages']];