<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-07-19 18:43:18+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'pt','messages'=>['Editor NameClassic Editor'=>'Editor clássico','Editor NameBlock editor'=>'Editor de blocos','Editor NameClassic editor'=>'Editor clássico','Editor NameEdit (classic editor)'=>'Editar (Editor clássico)','Editor NameEdit (block editor)'=>'Editar (Editor de blocos)','Change settings'=>'Alterar opções','Default editor for all sites'=>'Editor por omissão para todos os sites','Editor Settings'=>'Opções do editor','Default Editor'=>'Editor por omissão','Editor Nameblock editor'=>'Editor de blocos','Editor Nameclassic editor'=>'Editor clássico','Edit &#8220;%s&#8221; in the block editor'=>'Editar &#8220;%s&#8221; no editor de blocos','Switch to block editor'=>'Mudar para o editor de blocos','Switch to classic editor'=>'Mudar para o editor clássico','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Por omissão o editor de blocos é substituído pelo editor clássico e os utilizadores não podem mudar de editor.','Allow site admins to change settings'=>'Permitir aos administradores do site alterar as opções','Editor'=>'Editor','No'=>'Não','Yes'=>'Sim','Allow users to switch editors'=>'Permitir aos utilizadores mudar de editor','Default editor for all users'=>'Editor por omissão para todos os utilizadores','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://pt.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress Contributors','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Activa o editor clássico do WordPress e o ecrã de edição de conteúdos com TinyMCE, metaboxes, etc. Suporta os plugins mais antigos que funcionam com o ecrã de edição clássico.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Editar &#8220;%s&#8221; no editor clássico','Settings'=>'Opções']];