<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-01-24 04:57:54+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'ja_JP','messages'=>['Editor NameClassic Editor'=>'旧エディター','Editor NameBlock editor'=>'ブロックエディター','Editor NameClassic editor'=>'旧エディター','Editor NameEdit (classic editor)'=>'編集 (旧エディター)','Editor NameEdit (block editor)'=>'編集 (ブロックエディター) ','Change settings'=>'設定変更','Default editor for all sites'=>'すべてのサイトのデフォルトエディター','Editor Settings'=>'エディター設定','Default Editor'=>'デフォルトエディター','Editor Nameblock editor'=>'ブロックエディター','Editor Nameclassic editor'=>'旧エディター','Edit &#8220;%s&#8221; in the block editor'=>'「%s」をブロックエディターで編集','Switch to block editor'=>'ブロックエディターに切り替え','Switch to classic editor'=>'旧エディターに切り替え','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'デフォルトでは、ブロックエディターがクラッシックエディターに置き換えられ、ユーザーはエディターを切り替えることはできません。','Allow site admins to change settings'=>'サイト管理者による設定の変更を許可','Editor'=>'エディター','No'=>'いいえ','Yes'=>'はい','Allow users to switch editors'=>'ユーザーにエディターの切り替えを許可','Default editor for all users'=>'すべてのユーザーのデフォルトエディター','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://ja.wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'WordPress コントリビューター','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'WordPress の旧エディターと、TinyMCE、メタボックスなどを含む以前のスタイルの投稿編集画面レイアウトを有効化します。この画面を拡張する古いプラグインをサポートします。','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'「%s」を旧エディターで編集','Settings'=>'設定']];