<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2025-10-17 20:53:06+0000','plural-forms'=>'nplurals=1; plural=0;','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'zh_TW','messages'=>['Dashboard'=>'控制台','WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'如果想使用 WordPress 建置簡易電子商務網站，可以使用','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: 請注意，如果在這個網站上啟用了使用 comment_registration option 的 [使用者必須註冊並完成登入才能發佈留言] 選項，在 [留言] 區塊中便無法隱藏登入連結。','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: 請注意，如果選取了使用 comment_registration option 的 [使用者必須註冊並完成登入才能發佈留言] 選項，在 [留言] 區塊中便無法隱藏登入連結。','WPServeur, NicolasKulka, wpformation'=>'WPServeur、NicolasKulka 及 wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'當有未登入的人員試圖存取 wp-login.php 頁面及 wp-admin 目錄時，將他重新導向至指定網址頁面。','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'透過變更登入網址的方式保護網站，並防止未經授權的人員存取 wp-login.php 頁面及 wp-admin 目錄。','WPS Limit Login'=>'WPS Limit Login','and'=>'及','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'外掛','Discover our other plugins:'=>'我們提供的其他外掛:','WordPress specialized hosting'=>'(WPServeur 是專營 WordPress 的主機代管服務提供商)','Redirection url'=>'重新導向網址','Redirection url default'=>'重新導向網址預設值','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'這項功能已停用。','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'透過變更登入網址的方式保護網站，並防止未登入的人員存取 wp-login.php 頁面及 wp-admin 目錄。','This feature is not enabled.'=>'這項功能尚未啟用。','Settings'=>'設定','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'這個網站變更後的登入頁面: <strong><a href="%1$s">%2$s</a></strong>。請將這個頁面加入瀏覽器書籤。','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'如需變更 [多站網路登入網址全域預設值] 設定，請前往 [<a href="%s">多站網路設定</a>] 頁面。','Login url'=>'登入網址','Networkwide default'=>'多站網路登入網址全域預設值','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'如果使用上遇到問題，請前往<a href="%1$s" target="_blank">技術支援論壇</a>尋求協助。這個外掛由 <a href="%2$s" target="_blank">WPServeur</a> 開發提供。','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'這項設定可讓多站網路管理員設定多站網路登入網址全域預設值，但個別網站的設定可覆寫這個預設值。個別網站如需變更這項設定，請前往 [永久連結] 變更登入網址。','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'由於這個網站已啟用 Rename wp-login.php 外掛，因此 WPS Hide Login 無法啟用。請先將 Rename wp-login.php 解除安裝，才能使用 WPS Hide Login。','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'請升級至 WordPress 最新版本以啟用']];