<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-05-22 09:16:56+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'da_DK','messages'=>['Editor NameClassic Editor'=>'Klassisk Editor','Editor NameClassic editor'=>'Klassisk Editor','Editor NameBlock editor'=>'Blok Editor','Default Editor'=>'Standard editor','Default editor for all sites'=>'Standard editor til alle websteder','Change settings'=>'Ændre indstillinger','Editor Settings'=>'Editor indstillinger','Editor NameEdit (block editor)'=>'Rediger (blok editor)','Editor NameEdit (classic editor)'=>'Rediger (klassisk editor)','Editor Nameblock editor'=>'blok editor','Editor Nameclassic editor'=>'klassisk editor','Edit &#8220;%s&#8221; in the block editor'=>'Rediger &#8220;%s&#8221; i blok editoren','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','Default editor for all users'=>'Standard editor for alle brugere','Allow users to switch editors'=>'Tillad brugere at skifte editors','Yes'=>'Ja','No'=>'Nej','Editor'=>'Editor','Allow site admins to change settings'=>'Tillad websteds admins at ændre indstillinger','Switch to block editor'=>'Skift til blok editor','Switch to classic editor'=>'Skift til klassisk editor','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Som standard erstattes blok editoren med den klassiske editor og brugere kan ikke skifte editorer.','Classic Editor'=>'Klassisk editor','Settings'=>'Indstillinger','Edit &#8220;%s&#8221; in the classic editor'=>'Rediger &#8220;%s&#8221; i den klassiske editor','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Aktivere WordPress klassiske editor og gamle stil med redigere sider og indlæg med TinyMCE, Meta bokse osv. Understøtter de ældre plugin\'er som virkede med editoren.','WordPress Contributors'=>'WordPress Contributors']];