<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2024-07-05 11:26:20+0000','plural-forms'=>'nplurals=3; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - WPS Hide Login - Stable (latest release)','language'=>'uk_UA','messages'=>['WPBoutik'=>'WPBoutik','You want to find out how to simplify ecommerce with WordPress, try'=>'Якщо ви хочете дізнатися, як спростити електронну комерцію за допомогою WordPress, спробуйте','WPS Hide Login : Please note that the comment_registration option “Users must be registered and logged in to comment” is activated on your site, the connection link will not be hidden on the comments block.'=>'WPS Hide Login: Зверніть увагу, що опція реєстрації коментарів «Користувачі повинні бути зареєстровані та увійшли, щоб залишити коментар» активована на вашому сайті, зв\'язок не буде прихований у блоку коментарів.','WPS Hide Login : Please note, if you check the comment_registration option "Users must be registered and logged in to comment", the login link will not be hidden on the comment block.'=>'WPS Hide Login: Зверніть увагу, якщо ви встановите опцію реєстрації коментарів «Користувачі повинні бути зареєстровані та увійшли в систему, щоб залишити коментар», посилання на вхід не буде приховано на блоку коментарів.','WPServeur, NicolasKulka, wpformation'=>'WPServeur, NicolasKulka, wpformation','Redirect URL when someone tries to access the wp-login.php page and the wp-admin directory while not logged in.'=>'Перенаправлення URL-адреси, коли хтось намагається отримати доступ до сторінки wp-login.php і каталогу wp-admin, не ввійшовши в систему.','Protect your website by changing the login URL and preventing access to the wp-login.php page and the wp-admin directory to non-connected people.'=>'Захистіть свій веб-сайт, змінивши URL-адресу входу та заборонивши доступ до сторінки wp-login.php і каталогу wp-admin для людей, які не підключені до мережі.','WPS Limit Login'=>'WPS Limit Login','and'=>'і','WPS Cleaner'=>'WPS Cleaner','WPS Bidouille'=>'WPS Bidouille','the plugin'=>'плагін','Discover our other plugins:'=>'Відкрийте для себе інші плагіни:','WordPress specialized hosting'=>'Спеціалізований хостинг WordPress','Redirection url'=>'URL-адреса перенаправлення','Redirection url default'=>'URL-адреса перенаправлення за умовчанням','https://wpserveur.net'=>'https://wpserveur.net','This has been disabled'=>'Це було вимкнено','Protect your website by changing the login URL and preventing access to wp-login.php page and wp-admin directory while not logged-in'=>'Захистіть свій веб-сайт, шляхом зміни URL-адреси для входу та заборони доступу до сторінки wp-login.php та до каталогу wp-admin, поки не увійшли в систему','This feature is not enabled.'=>'Ця функція не увімкнена.','Settings'=>'Налаштування','Your login page is now here: <strong><a href="%1$s">%2$s</a></strong>. Bookmark this page!'=>'Ваша сторінка для входу відтепер знаходиться тут: <strong><a href="%1$s">%2$s</a></strong>. Збережіть її у закладках!','To set a networkwide default, go to <a href="%s">Network Settings</a>.'=>'Щоб встановити налаштування за замовчуванням у всій мережі, перейдіть до <a href="%s">Налаштувань мережі</a>.','Login url'=>'URL для входу','Networkwide default'=>'Мережа за замовчуванням','Need help? Try the <a href="%1$s" target="_blank">support forum</a>. This plugin is kindly brought to you by <a href="%2$s" target="_blank">WPServeur</a>'=>'Потрібна допомога? Спробуйте звернутися на <a href="%1$s" target="_blank">форум підтримки</a>. Цей плагін люб\'язно представлений <a href="%2$s" target="_blank">WPServeur</a>','This option allows you to set a networkwide default, which can be overridden by individual sites. Simply go to to the site’s permalink settings to change the url.'=>'Цей параметр дозволяє встановити за замовчуванням мережу, яка може бути змінена окремими сайтами. Просто перейдіть до налаштувань постійних посилань сайту, щоб змінити URL-адресу.','WPS Hide Login could not be activated because you already have Rename wp-login.php active. Please uninstall rename wp-login.php to use WPS Hide Login'=>'Неможливо активувати WPS Hide Login тому, що вже активовано плагін Rename wp-login.php. Видаліть, будь ласка, плагін Rename wp-login.php, щоб використовувати WPS Hide Login','WPS Hide Login'=>'WPS Hide Login','Please upgrade to the latest version of WordPress to activate'=>'Будь ласка, оновіть WordPress до останньої версії, щоб активувати']];