<?php
return ['x-generator'=>'GlotPress/4.0.1','translation-revision-date'=>'2025-08-26 21:48:48+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Classic Editor - Stable (latest release)','language'=>'sv_SE','messages'=>['Editor NameClassic Editor'=>'Klassisk redigerare','Editor NameBlock editor'=>'Blockredigerare','Editor NameClassic editor'=>'Klassisk redigerare','Editor NameEdit (classic editor)'=>'Redigera (klassisk redigerare)','Editor NameEdit (block editor)'=>'Redigera (blockredigerare)','Change settings'=>'Ändra inställningar','Default editor for all sites'=>'Standardredigerare för alla webbplatser','Editor Settings'=>'Inställningar för redigerare','Default Editor'=>'Standardredigerare','Editor Nameblock editor'=>'blockredigerare','Editor Nameclassic editor'=>'klassisk redigerare','Edit &#8220;%s&#8221; in the block editor'=>'Redigera "%s" i blockredigeraren','Switch to block editor'=>'Byt till blockredigeraren','Switch to classic editor'=>'Byt till klassisk redigerare','By default the block editor is replaced with the classic editor and users cannot switch editors.'=>'Som standard ersätts blockredigeraren av den klassiska redigeraren och användarna kan inte växla mellan redigeringsmiljöerna.','Allow site admins to change settings'=>'Tillåt webbplatsadministratörer att ändra inställningar','Editor'=>'Redigerare','No'=>'Nej','Yes'=>'Ja','Allow users to switch editors'=>'Låt användare byta redigerare','Default editor for all users'=>'Standardredigerare för alla användare','https://github.com/WordPress/classic-editor/'=>'https://github.com/WordPress/classic-editor/','https://wordpress.org/plugins/classic-editor/'=>'https://wordpress.org/plugins/classic-editor/','WordPress Contributors'=>'Bidragsgivare till WordPress','Enables the WordPress classic editor and the old-style Edit Post screen with TinyMCE, Meta Boxes, etc. Supports the older plugins that extend this screen.'=>'Aktiverar den klassiska redigeraren i WordPress och den tidigare layouten av sidan för redigering av inlägg, med TinyMCE, metafält m.m.. Stöder äldre WordPress-tillägg som utökar denna skärmbild.','Classic Editor'=>'Classic Editor','Edit &#8220;%s&#8221; in the classic editor'=>'Redigera ”%s” i den klassiska redigeraren','Settings'=>'Inställningar']];