<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2025-12-03 19:00:15+0000','plural-forms'=>'nplurals=3; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : ((n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14)) ? 1 : 2);','project-id-version'=>'Plugins - FileOrganizer &#8211; WordPress File Manager - Stable (latest release)','language'=>'ru','messages'=>['Important'=>'Важно','File type is not allowed.'=>'Неподходящий тип файла.','Settings'=>'Настройки','License'=>'Лицензия','Theme'=>'Тема','Default'=>'По умолчанию','Dark'=>'Темная','Material'=>'Материал','Settings saved successfully.'=>'Настройки успешно сохранены.','General'=>'Общие','Advanced'=>'Дополнительно','Support'=>'Поддержка','Icons'=>'Значки','List'=>'Список','Select Language'=>'Выбрать язык','Administrator'=>'Админ','Editor'=>'Редактор','Author'=>'Автор','Contributor'=>'Участник','Subscriber'=>'Подписчик','Customer'=>'Клиент','MB'=>'Мб','here'=>'здесь','User Role Restrictions'=>'Ограничения ролей пользователей','Material Light'=>'Материал светлый','Windows 10'=>'Windows 10','Hide .htaccess?'=>'Скрыть .htaccess?','Enable Trash?'=>'Включить корзину?','Available in Pro version!'=>'Доступно в Pro версии!','Allowed User Roles'=>'Разрешенные роли пользователей','Shop Manager'=>'Менеджер магазина','Maximum Upload Size'=>'Макс. размер загрузки','or through Our Premium Support Ticket System at'=>'или через нашу систему обращений в службу поддержки премиум-класса по адресу','FileOrganizer'=>'FileOrganizer','https://wordpress.org/plugins/fileorganizer/'=>'https://wordpress.org/plugins/fileorganizer/','FileOrganizer is a plugin that helps you to manage all files in your WordPress Site.'=>'FileOrganizer - это плагин, который поможет вам управлять всеми файлами на вашем сайте WordPress.','Softaculous Team'=>'Softaculous Team','https://fileorganizer.net'=>'https://fileorganizer.net','FILE ORGANIZER'=>'ОРГАНИЗАТОР ФАЙЛОВ','File Organizer'=>'Организатор файлов']];